==> haskell-bytestring-tree-builder-0.2.7.13-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-tree-builder
version:              0.2.7.13
visibility:           public
id:                   bytestring-tree-builder-0.2.7.13-LGyn1kQCiu3D78E7j9fhCY
key:                  bytestring-tree-builder-0.2.7.13-LGyn1kQCiu3D78E7j9fhCY
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  80a58f0c6080eb78a7dd8ad4e87a4a60
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Prelude
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.13-LGyn1kQCiu3D78E7j9fhCY
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.13-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-tree-builder
version:              0.2.7.13
visibility:           public
id:                   bytestring-tree-builder-0.2.7.13-AVouewDLhx6CH7quWzml6Y
key:                  bytestring-tree-builder-0.2.7.13-AVouewDLhx6CH7quWzml6Y
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  bc46b28a4271b5c437c9cae2868d487e
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Prelude
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/bytestring-tree-builder-0.2.7.13

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.13-AVouewDLhx6CH7quWzml6Y
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
